@@ -1,4 +1,5 @@
-from .general import default_print
+from .general import builtin_print
+from .general import builtin_print as bprint  # alias
 from .global_control import disable
 from .global_control import enable
 from .global_control import setup
@@ -7,4 +8,4 @@ from .global_control import unload
 from .global_control import update
 from .logger import lk
 
-__version__ = '5.2.3'
+__version__ = '5.2.4'
